.. currentmodule:: pyfits

*****************
Header Data Units
*****************

.. inheritance-diagram:: PrimaryHDU ImageHDU GroupsHDU TableHDU BinTableHDU StreamingHDU

The `ImageHDU` and `CompImageHDU` classes are discussed in the
section on :ref:`Images`.

The `TableHDU` and `BinTableHDU` classes are discussed in the
section on :ref:`Tables`.

`PrimaryHDU`
============

.. autoclass:: PrimaryHDU
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`GroupsHDU`
===========

.. autoclass:: GroupsHDU
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`StreamingHDU`
==============

.. autoclass:: StreamingHDU
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:
